@@ -669,8 +669,8 @@ MSVARmdl_mle <- function(theta_0, mdl_in, k, optim_options){
   res <- nloptr::slsqp(x0 = theta_0,
                        fn = logLike_MSVARmdl_min,
                        gr = NULL,
-                       lower = NULL,
-                       upper = NULL,
+                       lower = optim_options$lower,
+                       upper = optim_options$upper,
                        hin = loglik_const_ineq_MSVARmdl,
                        heq = loglik_const_eq_MSVARmdl,
                        nl.info = FALSE,
