@@ -12,6 +12,3 @@ lmc_control = list(N = 99,
 lmc_gnp84 <- DLMCTest(y84, p = 4, control = lmc_control)
 lmc_gnp84
 
-# perform test on extended data used in CHP 2014
-lmc_gnp10 <- DLMCTest(y10, p = 4, control = lmc_control)
-lmc_gnp10
