@@ -27,7 +27,5 @@ lmc_control = list(N = 19,
                                          use_diff_init = 1))
 
 
-mdl <- LMCLRTest(y_ms_simu$y, p = 1, k0 = 1 , k1 = 2, lmc_control)
-mdl
-
-
+#mdl <- LMCLRTest(y_ms_simu$y, p = 1, k0 = 1 , k1 = 2, lmc_control)
+#mdl
